@@ -24,17 +24,31 @@ coef(f) - coef(g)
 f
 g
 
+P
 Predict(f, bmi=20, offset=list(wtpre=5))   # 4.849534
 d <- data.frame(bmi=20, wtpre=5)
 predict(f, d)       # 4.849534
 k <- coef(f)
-with(d, - f$center + k[1]*bmi + k[2] * bmi^2 + k[3] * bmi^3 + wtpre)  # 4.849534
-## predict(g, d)   # bombs
+mp <- function(fit, bmi=20, wtpre=5) {
+  k  <- coef(fit)
+  k0 <- if(length(fit$center)) - fit$center
+  else {
+    m  <- fit$means
+    k0 <- - unname(k[1] * m[1] + k[2] * m[2] + k[3] * m[3])
+    }
+  k0 + k[1]*bmi + k[2] * bmi^2 + k[3] * bmi^3 + wtpre
+}
+mp(f)   # 4.849534
+mp(g)   # "
 
 f <- cph(S ~ pol(bmi, 3) + offset(wtpre), data=cvd, eps=1e-6)
-g <- coxph(S ~ pol(bmi, 3) + offset(wtpre), data=cvd)
+g <- coxph(S ~ pol(bmi, 3) + offset(wtpre), data=cvd,
+           control=coxph.control(eps=1e-6))
 coef(f) - coef(g)
-predict(f, d)
+mp(f)   # 4.849534
+mp(g)   # "
+predict(f, d)   # -.1504; ignores offset
+Predict(f, bmi=20, offset=list(wtpre=5))   # -.1504
 
 p1 <- Predict(f, bmi, offset=list(wtpre=0))
 p2 <- Predict(f, bmi, offset=list(wtpre=5))
